#
# spec file
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define octpkg  doctest
Name:           octave-forge-%{octpkg}
Version:        0.8.0
Release:        1.7
Summary:        Octave-Forge documentation tests
License:        BSD-3-Clause AND GPL-3.0-or-later
Group:          Productivity/Scientific/Math
URL:            https://octave.sourceforge.io
Source0:        https://downloads.sourceforge.net/octave/%{octpkg}-%{version}.tar.gz
BuildRequires:  gcc-c++
BuildRequires:  octave-devel >= 4.2.0
Requires:       octave-cli >= 4.2.0
BuildArch:      noarch

%description
The Octave-Forge Doctest package finds specially-formatted blocks of example
code within documentation files. It then executes the code and confirms
the output is correct. This can be useful as part of a testing framework
or simply to ensure that documentation stays up-to-date during software development.
This is part of Octave-Forge project.

%prep
%setup -q -c %{name}-%{version}
%octave_pkg_src

%build
%octave_pkg_build

%install
%octave_pkg_install

%check
tar -zxvf %{octpkg}-%{version}.tar.gz
%octave_pkg_test

%post
%octave --eval "pkg rebuild"

%postun
%octave --eval "pkg rebuild"

%files
%defattr(-,root,root)
%{octpackages_dir}/%{octpkg}-%{version}

%changelog
* Wed Jan  4 2023 Dirk Müller <dmueller@suse.com>
- update to 0.8.0:
  * Expected error messages can be optionally prefixed with "error: ".
  * Writing "??? " at the beginning of an error is now deprecated.
  * Texinfo users can markup errors with `@error{}`.
  * `doctest myclass` has been refactored with various bugs fixed.
  * Preliminary support for `doctest classdef.method` on Octave.
  * Test classdef methods using dotted `classdef.method` while still
    using `@class/method` on old-style classes.
  * Functions defined directly in the Octave interpreter can now be tested.
  * Test suite fixes for Octave 6 and 7.
  * Source code is encoded with UTF-8, indicated with `.oct-config` files.
  * Don't doctest some classdef methods twice.
* Wed Nov 27 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 0.7.0:
  * Functions within compiled `.oct` files can now be tested.
  * Tests are run with default number formatting (see `help doctest`).
  * More robust to errors during testing.
  * Makefile improvements and fixes.
* Wed Jul 18 2018 badshah400@gmail.com
- Update to version 0.6.1:
  * Workaround regex bug on ARM (again!).
- Changes from version 0.6.0:
  * Tests can now call "clear" and "clear all".
  * Fixes for running on Octave development versions (upcoming
    4.4.0).
  * Minimum supported Octave version is now 4.2.0.  The package no
    longer has any compiled code and does not include an "evalc"
    implementation.
- Update Requires: octave-cli > 4.2.0 is now required.
- Update file list: pkg no longer installs to libdir.
- BuildArch: noarch because pkg no longer installs arch dependent
  binaries.
- Untar tarball in build dir before running checks.
* Thu Nov 24 2016 dmitry_r@opensuse.org
- Update to version 0.5.0
  * SKIP_IF and other conditional directives can include small single-line
    blocks of code.
  * Recursion into subdirectories is now the default.
  * In Texinfo mode, skip tests without output by default.
* Sat Jun 11 2016 dmitry_r@opensuse.org
- Update to version 0.4.1
  * Added conditional variants of SKIP and XFAIL directives to control test
    execution based on runtime conditions.
  * Added constants DOCTEST_OCTAVE and DOCTEST_MATLAB that can be used as
    conditions in SKIP_IF etc.
  * Improved handling of example code in TexInfo documentation.
  * Improved folder/directory traversals.
* Tue Jul 14 2015 dmitry_r@opensuse.org
- Initial package, version 0.4.0
